
=======================================
Python for Everybody - Interactive
=======================================

.. Here is were you specify the content and order of your new book.

.. Each section heading (e.g. "SECTION 1: A Random Section") will be
   a heading in the table of contents. Source files that should be
   generated and included in that section should be placed on individual
   lines, with one line separating the first source filename and the
   :maxdepth: line.

.. Sources can also be included from subfolders of this directory.
   (e.g. "DataStructures/queues.rst").

Assignments
:::::::::::::::::

.. raw:: html

   <ul>
   <li><a href="/runestone/assignments/chooseAssignment.html">Assignments</a></li>
   </ul>

Table of Contents
:::::::::::::::::::::::::::::::

.. toctree::
   :numbered:
   :maxdepth: 3

   intro/toctree.rst
   variables/toctree.rst
   debugging/toctree.rst
   conditional/toctree.rst
   functions/toctree.rst
   iterations/toctree.rst
   strings/toctree.rst
   files/toctree.rst
   lists/toctree.rst
   dictionaries/toctree.rst
   tuples/toctree.rst
   regex/toctree.rst
   network/toctree.rst
   bsoup/toctree.rst
   web/toctree.rst
   objects/toctree.rst
   turtles/toctree.rst
   pictures/toctree.rst
   classes-basics/toctree.rst
   inheritance/toctree.rst
   database/toctree.rst
   viz/toctree.rst

Acknowledgements
::::::::::::::::

.. toctree::
   :caption: Acknowledgements, Contributors, License, and Preface
   :maxdepth: 1

   ack/AA-contrib.rst
   ack/AB-copyright.rst
   ack/A0-preface.rst

Indices
::::::::::::::::::

* :ref:`genindex`
* :ref:`search`
